@@ -15,7 +15,7 @@ use constant FFR     => 'File::Find::Rule';
 
 use vars qw{$VERSION};
 BEGIN {
-        $VERSION = '0.21';
+        $VERSION = '0.22';
 }
 
 # Does exec work on this platform
@@ -71,6 +71,10 @@ sub lib () {
 	catdir( curdir(), 'lib' );
 }
 
+sub t () {
+	catdir( curdir(), 't' );
+}
+
 
 
 
@@ -78,14 +82,6 @@ sub lib () {
 #####################################################################
 # Convenience Logic
 
-sub in_distroot () {
-	!! -f MakefilePL;
-}
-
-sub in_subdir () {
-        !! -f catfile( updir(), 'Makefile.PL' );
-}
-
 sub has_makefile () {
 	!! -f Makefile;
 }
@@ -102,6 +98,24 @@ sub has_lib () {
 	!! -d lib;
 }
 
+sub has_t () {
+	!! -d t;
+}
+
+sub in_distroot () {
+	!! (
+		has_makefilepl or (has_lib and has_t)
+	);
+}
+
+sub in_subdir () {
+        !! (
+		-f catfile( updir(), 'Makefile.PL' )
+		or
+		-d catdir( updir(), 't' )
+	);
+}
+
 sub needs_makefile () {
 	has_makefilepl and ! has_makefile;
 }
